==> parodia_admin-1.0.2.tar.gz: lib/core/repository/ticket.repository.dart <==
// GET
// /api/v1/dashboard/tickets/categories

// GET
// /api/v1/dashboard/tickets/{id}

// DELETE
// /api/v1/dashboard/tickets/{id}

// GET
// /api/v1/dashboard/tickets

// POST
// /api/v1/dashboard/tickets

// POST
// /api/v1/dashboard/tickets/{id}/message

// PUT
// /api/v1/dashboard/tickets/{id}/delegate

// PUT
// /api/v1/dashboard/tickets/{id}/assign

// POST
// /api/v1/dashboard/tickets/{id}/recover

import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/ticket.dto.dart';
import 'package:parodia_admin/core/dto/ticket_category.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class TicketRepository {
  ParodiaHTTP? _http;

  TicketRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseListDTO<TicketCategoryDTO>> getCategories() async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/tickets/categories',
    );

    return ResponseListDTO<TicketCategoryDTO>(
      response: response,
      fromJson: TicketCategoryDTO.fromJson,
    );
  }

  Future<ResponseItemDTO<TicketDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/tickets',
      param: id,
    );

    return ResponseItemDTO<TicketDTO>(
      response: response,
      fromJson: TicketDTO.fromJson,
    );
  }

  Future<ResponseListDTO<TicketDTO>> getAll({TicketQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/tickets',
      query: query,
    );

    return ResponseListDTO<TicketDTO>(
      response: response,
      fromJson: TicketDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({ThemeBody? theme}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/tickets',
      data: theme,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, ThemeBody? theme}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/tickets',
      param: id,
      data: theme,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/tickets',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/tickets/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> addMessage(
      {String? id, TicketMessageBody? message}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/tickets/$id/message',
      data: message,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delegate({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/tickets/$id/delegate',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> assign(
      {String? id, TicketAssignPutBody? assign}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/tickets/$id/assign',
      data: assign,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}

==> parodia_admin-1.0.20.tar.gz: lib/core/repository/ticket.repository.dart <==
// GET
// /api/v1/dashboard/dashboard/tickets/categories

// GET
// /api/v1/dashboard/dashboard/tickets/{id}

// DELETE
// /api/v1/dashboard/dashboard/tickets/{id}

// GET
// /api/v1/dashboard/dashboard/tickets

// POST
// /api/v1/dashboard/dashboard/tickets

// POST
// /api/v1/dashboard/dashboard/tickets/{id}/message

// PUT
// /api/v1/dashboard/dashboard/tickets/{id}/delegate

// PUT
// /api/v1/dashboard/dashboard/tickets/{id}/assign

// POST
// /api/v1/dashboard/dashboard/tickets/{id}/recover

import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/ticket.dto.dart';
import 'package:parodia_admin/core/dto/ticket_category.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class TicketRepository {
  ParodiaHTTP? _http;

  TicketRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseListDTO<TicketCategoryDTO>> getCategories() async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/tickets/categories',
    );

    return ResponseListDTO<TicketCategoryDTO>(
      response: response,
      fromJson: TicketCategoryDTO.fromJson,
    );
  }

  Future<ResponseItemDTO<TicketDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/tickets',
      param: id,
    );

    return ResponseItemDTO<TicketDTO>(
      response: response,
      fromJson: TicketDTO.fromJson,
    );
  }

  Future<ResponseListDTO<TicketDTO>> getAll({TicketQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/tickets',
      query: query,
    );

    return ResponseListDTO<TicketDTO>(
      response: response,
      fromJson: TicketDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({ThemeBody? theme}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/tickets',
      data: theme,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, ThemeBody? theme}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/tickets',
      param: id,
      data: theme,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/tickets',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/tickets/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> addMessage(
      {String? id, TicketMessageBody? message}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/tickets/$id/message',
      data: message,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delegate({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/tickets/$id/delegate',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> assign(
      {String? id, TicketAssignPutBody? assign}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/tickets/$id/assign',
      data: assign,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
